summaryrefslogtreecommitdiff
path: root/sw/source/filter/ww8/rtfexport.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/filter/ww8/rtfexport.cxx')
-rw-r--r--sw/source/filter/ww8/rtfexport.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/filter/ww8/rtfexport.cxx b/sw/source/filter/ww8/rtfexport.cxx
index f6dcdf3cecf8..f37e7e8ce415 100644
--- a/sw/source/filter/ww8/rtfexport.cxx
+++ b/sw/source/filter/ww8/rtfexport.cxx
@@ -802,8 +802,8 @@ void RtfExport::ExportDocument_Impl()
const SwFormatFrameSize& rSz = rFormatPage.GetFrameSize();
// Clipboard document is always created without a printer, then
- // the size will be always LONG_MAX! Solution then is to use A4
- if (LONG_MAX == rSz.GetHeight() || LONG_MAX == rSz.GetWidth())
+ // the size will be always SAL_MAX_INT32! Solution then is to use A4
+ if (SAL_MAX_INT32 == rSz.GetHeight() || SAL_MAX_INT32 == rSz.GetWidth())
{
Strm().WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PAPERH);
Size a4 = SvxPaperInfo::GetPaperSize(PAPER_A4);